@@ -1,6 +1,6 @@
 from typing import Union
 
-from attr import dataclass
+from dataclasses import dataclass
 
 
 NOT_SET = object()
